boss.starter - heros-boss unknown documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# boss.starter

## Functions

`create_unique_instance_name`(→ str) | Creates a unique instance identifier consisting of the hostname and an UUID.
`run`([args]) |

## Module Contents

boss.starter.create_unique_instance_name() → str

  Creates a unique instance identifier consisting of the hostname and an UUID.

  Returns:

    A unique identifier.

boss.starter.run(args=None)